﻿using System;
using System.Collections.Generic;
using System.IO;
using Telerik.Windows.Controls;

namespace SilverlightApp.Web
{
	public class MyRadUploadHandler : Telerik.Windows.RadUploadHandler
	{
		public MyRadUploadHandler()
		{
		}

		public override void ProcessStream()
		{
			string fileName = this.Request.Form[RadUploadConstants.ParamNameFileName];
			int dotPosition = fileName.LastIndexOf('.');
			if (dotPosition >= 0)
			{
				fileName = fileName.Insert(dotPosition, ".(myLabel)");
			}
			else
			{
				fileName += "_(myLabel)";
			}

			string filePath = this.GetFilePath(fileName);

			this.AddReturnParam(RadUploadConstants.ParamNameFinalFileRequest, this.IsFinalFileRequest());

			if (filePath == null)
			{
				this.AddReturnParam(RadUploadConstants.ParamNameSuccess, false);
				this.AddReturnParam(RadUploadConstants.ParamNameMessage, String.Format("Cannot find the target folder [{0}]", this.GetTargetFolder()));
				return;
			}
			else if (this.IsNewFileRequest() && File.Exists(filePath) && !this.OverwriteExistingFiles)
			{
				this.AddReturnParam(RadUploadConstants.ParamNameSuccess, false);
				this.AddReturnParam(RadUploadConstants.ParamNameMessage, String.Format("File already exists name:[{0}], path:[{1}]", fileName, filePath));
				return;
			}

			byte[] buffer;
			try
			{
				buffer = Convert.FromBase64String(this.Request.Form[RadUploadConstants.ParamNameData]);
			}
			catch (System.FormatException)
			{
				this.AddReturnParam(RadUploadConstants.ParamNameSuccess, false);
				this.AddReturnParam(RadUploadConstants.ParamNameMessage, "Bad stream format");
				return;
			}

			long position = Convert.ToInt64(this.Request.Form[RadUploadConstants.ParamNamePosition]);
			long contentLength = 0;
			FileStream stream = null;
			try
			{
				// remove any old file with the same name
				if (this.IsNewFileRequest())
				{
					if (File.Exists(filePath))
					{
						this.RemoveFile(filePath);
					}
				}

				stream = File.OpenWrite(filePath);
				stream.Position = position;
				stream.Write(buffer, 0, buffer.Length);
				contentLength = stream.Length;
			}
			catch (Exception e)
			{
				this.AddReturnParam(RadUploadConstants.ParamNameSuccess, false);
				this.AddReturnParam(RadUploadConstants.ParamNameMessage, String.Format("Cannot open the file for writing [{0}]", e.Message));
			}
			finally
			{
				if (stream != null)
				{
					stream.Dispose();
				}
			}

			if (contentLength == 0)
			{
				return;
			}

			buffer = null;

			this.AddReturnParam(RadUploadConstants.ParamNameSuccess, true);

			if (this.IsFinalFileRequest())
			{
				this.AddReturnParam(RadUploadConstants.ParamNameFileIdent, filePath);
				this.AddReturnParam(RadUploadConstants.ParamNameFileName, fileName);
				this.AddReturnParam(RadUploadConstants.ParamNameFilePath, filePath);

				// serialize the custom params
				string associatedDataString = String.Empty;

				Dictionary<string, object> associatedData = this.GetAssociatedData();
				if (associatedData.Count > 0)
				{
					foreach (string key in associatedData.Keys)
					{
						object value = associatedData[key];
						if (value == null)
						{
							value = "null";
						}

						value = "\"" + value.ToString().Replace("\\", "\\\\") + "\"";
						associatedDataString += "{" + String.Format(@"""Key"":""{0}"",""Value"":{1}", key, value) + "},";
					}

					associatedDataString = associatedDataString.TrimEnd(',');
				}

				this.AddReturnParam(RadUploadConstants.ParamNameAssociatedData, associatedDataString);
			}

			this.AddReturnParam(RadUploadConstants.ParamNameFinalFileRequest, this.IsFinalFileRequest());
		}
	}
}
