﻿using System;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using Telerik.Windows;
using Telerik.Windows.Controls;

namespace SilverlightApp
{
	public partial class Page : UserControl
	{
		public Page()
		{
			InitializeComponent();
			this.Loaded += new RoutedEventHandler(Page_Loaded);
		}

		void Page_Loaded(object sender, RoutedEventArgs e)
		{
			System.Globalization.NumberFormatInfo info = new NumberFormatInfo();
			info.NumberDecimalDigits = 0;
			this.BufferSize.NumberFormatInfo = info;
			this.BufferSize.Value = this.radUpload.BufferSize;

			this.scrollViewer.AddHandler(Telerik.Windows.Input.Mouse.MouseWheelEvent,
				new EventHandler<Telerik.Windows.Input.MouseWheelEventArgs>(this.OnMouseWheel));
		}

		private void OnMouseWheel(object sender, Telerik.Windows.Input.MouseWheelEventArgs args)
		{
			double offset;
			const int accelerate = 5;
			if (scrollViewer.ComputedVerticalScrollBarVisibility == Visibility.Visible)
			{
				offset = scrollViewer.VerticalOffset - args.Delta * accelerate;
				if (offset > scrollViewer.ScrollableHeight)
				{
					scrollViewer.ScrollToVerticalOffset(scrollViewer.ScrollableHeight);
				}
				else
				{
					scrollViewer.ScrollToVerticalOffset(offset);
				}
			}
			else
			{
				offset = scrollViewer.HorizontalOffset - args.Delta * accelerate;
				if (offset > scrollViewer.ScrollableWidth)
				{
					scrollViewer.ScrollToHorizontalOffset(scrollViewer.ScrollableWidth);
				}
				else
				{
					scrollViewer.ScrollToHorizontalOffset(offset);
				}
			}
		}

		private void btnClearTrace_Click(object sender, System.Windows.RoutedEventArgs e)
		{
			this.traceOutput.Text = "";
		}

		private void RadUpload_FileCountExceeded(object sender, FileEventArgs e)
		{
			Status_EventEnter("FileCountExceeded");
			Status_AddRow("FileName" + e.SelectedFile.Name);
			Status_EventEnd("FileCountExceeded");
		}

		private void RadUpload_FilesSelected(object sender, FilesSelectedEventArgs e)
		{
			Status_EventEnter("FilesSelected");
			Status_AddRow("FileCount: " + e.SelectedFiles.Count);
			Status_AddRow("FirstFile Name: " + e.SelectedFiles[0].Name);
			Status_EventEnd("FilesSelected");
		}

		private void RadUpload_FileTooLarge(object sender, FileEventArgs e)
		{
			Status_EventEnter("FileTooLarge");
			Status_AddRow("File: " + e.SelectedFile.Name + " | " + e.SelectedFile.Size);
			Status_EventEnd("FileTooLarge");
		}

		private void RadUpload_FileUploaded(object sender, FileUploadedEventArgs e)
		{
			Status_EventEnter("FileUploaded");
			Status_AddRow("Uploaded File:" + e.SelectedFile.Name + " | " + e.HandlerData.IsSuccess);
			Status_EventEnd("FileUploaded");
		}

		private void RadUpload_FileUploadFailed(object sender, FileUploadFailedEventArgs e)
		{
			Status_EventEnter("FileUploadFailed");
			e.ErrorMessage = "My Message";
			Status_AddRow("Failed Message:" + e.HandlerData.Message);
			Status_EventEnd("FileUploadFailed");
		}

		private void RadUpload_FileUploadStarting(object sender, FileUploadStartingEventArgs e)
		{
			RadUpload upload1 = sender as RadUpload;
			Status_EventEnter("FileUploadStarting");
			e.FileParameters.Add("myParam1", "myParam1Value");
			Status_AddRow("Uploading File:" + e.SelectedFile.Name + " | " + e.UploadData.FileName);
			Status_EventEnd("FileUploadStarting");
		}

		private void RadUpload_ProgressChanged(object sender, EventArgs e)
		{
			RadUpload upload1 = sender as RadUpload;
			Status_EventEnter("ProgressChanged");
			DumpCurrentSession(sender);
			Status_EventEnd("ProgressChanged");
		}

		private void DumpCurrentSession(object sender)
		{
			RadUpload upload1 = sender as RadUpload;
			Status_AddRow("Current Progress:" + upload1.CurrentSession.CurrentProgress.ToString());
			Status_AddRow("Current File:" + upload1.CurrentSession.CurrentFile.Name);
			Status_AddRow("Current FileProgress:" + upload1.CurrentSession.CurrentFileProgress);
			Status_AddRow("TotalFilesCount:" + upload1.CurrentSession.TotalFilesCount);
			Status_AddRow("TotalFileSize:" + upload1.CurrentSession.TotalFileSize);
			Status_AddRow("UploadedBytes:" + upload1.CurrentSession.UploadedBytes);
			Status_AddRow("UploadedFilesCount:" + upload1.CurrentSession.UploadedFiles.Count);
		}

		private void RadUpload_UploadCanceled(object sender, EventArgs e)
		{
			RadUpload upload1 = sender as RadUpload;
			Status_EventEnter("UploadCanceled");
			Status_AddRow("Current File is:" + upload1.CurrentSession.CurrentFile.Name);
			Status_EventEnd("UploadCanceled");
		}

		private void RadUpload_UploadFinished(object sender, EventArgs e)
		{
			Status_EventEnter("UploadFinished");
			DumpCurrentSession(sender);
			Status_EventEnd("UploadFinished");
		}

		private void RadUpload_UploadPaused(object sender, EventArgs e)
		{
			Status_EventEnter("UploadPaused");
			Status_EventEnd("UploadPaused");
		}

		private void RadUpload_UploadResumed(object sender, EventArgs e)
		{
			Status_EventEnter("UploadResumed");
			Status_EventEnd("UploadResumed");
		}

		private void RadUpload_UploadSizeExceeded(object sender, RoutedEventArgs e)
		{
			Status_EventEnter("UploadSizeExceeded");
			Status_EventEnd("UploadSizeExceeded");
		}

		private void RadUpload_UploadStarted(object sender, UploadStartedEventArgs e)
		{
			Status_EventEnter("UploadStarted");
			Status_EventEnd("UploadStarted");
		}

		private void Status_EventEnter(string p)
		{
			this.Status_AddRow("------ " + p + " ----->");
		}

		private void Status_EventEnd(string p)
		{
			this.Status_AddRow("<----- " + p);
		}

		private void Status_AddRow(string info)
		{
			string s = info + "\n" + traceOutput.Text;
			const int maxLen = 32768;
			traceOutput.Text = (s.Length < maxLen) ? s : s.Substring(0, maxLen);
		}

		private void BufferSize_ValueChanged(object sender,
			System.Windows.RoutedPropertyChangedEventArgs<double> e)
		{
			if (this.radUpload != null)
			{
				this.radUpload.BufferSize = (int)this.BufferSize.Value;
			}
		}
	}
}
